==> cloudt-boot-starter-jpa-3.2.4.34-20230620.061034-1-sources.jar: com/elitescloud/boot/jpa/support/id/provider/snowflake/config/SnowflakeConfig.java <==
package com.elitescloud.boot.jpa.support.id.provider.snowflake.config;

import com.elitescloud.boot.jpa.support.id.config.IdProperties;
import com.elitescloud.boot.jpa.support.id.provider.snowflake.SnowflakeProvider;
import com.elitescloud.boot.jpa.support.id.provider.snowflake.assigner.DatabaseSnowflakeWorkerAssigner;
import com.elitescloud.boot.jpa.support.id.provider.snowflake.assigner.ManualSnowflakeWorkerAssigner;
import com.elitescloud.boot.jpa.support.id.provider.snowflake.assigner.RedisSnowflakeWorkerAssigner;
import com.elitescloud.boot.jpa.support.id.provider.snowflake.assigner.SnowflakeWorkerAssigner;
import com.elitescloud.boot.jpa.support.id.util.IdTool;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.jdbc.JdbcProperties;
import org.springframework.context.EnvironmentAware;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.lang.NonNull;

import javax.sql.DataSource;

/**
 * 雪花算法配置.
 *
 * @author Kaiser（wang shao）
 * @date 2022/12/8
 */
@ConditionalOnProperty(prefix = IdProperties.CONFIG_PREFIX, name = "gen-type", havingValue = "SNOWFLAKE", matchIfMissing = true)
public class SnowflakeConfig implements EnvironmentAware {
    @Value("${spring.application.name:#{'unknown'}}")
    private String dataCenterName;

    private final IdProperties idProperties;
    private final DataSource dataSource;
    private Environment environment;

    public SnowflakeConfig(IdProperties idProperties, DataSource dataSource) {
        this.idProperties = idProperties;
        this.dataSource = dataSource;
    }

    @Override
    public void setEnvironment(@NonNull Environment environment) {
        this.environment = environment;
    }

    @Bean
    public SnowflakeProvider snowflakeProvider(SnowflakeWorkerAssigner workerAssigner) {
        return new SnowflakeProvider(workerAssigner);
    }

    @Bean
    @ConditionalOnProperty(prefix = IdProperties.CONFIG_PREFIX, name = "assigner-type", havingValue = "MANUAL", matchIfMissing = true)
    public SnowflakeWorkerAssigner idGeneratorBuildableManual() {
        return new ManualSnowflakeWorkerAssigner(idProperties);
    }

    @Bean
    @ConditionalOnProperty(prefix = IdProperties.CONFIG_PREFIX, name = "assigner-type", havingValue = "DATABASE")
    public SnowflakeWorkerAssigner idGeneratorBuildableDatabase(JdbcProperties properties) {
        var jdbcTemplate = IdTool.buildJdbcTemplate(environment, dataSource, idProperties, properties);
        return new DatabaseSnowflakeWorkerAssigner(dataCenterName, idProperties, jdbcTemplate);
    }

    @Configuration
    @ConditionalOnBean(RedisTemplate.class)
    static class RedisSupportConfig {

        @Value("${spring.application.name:#{'unknown'}}")
        private String dataCenterName;

        private final IdProperties idProperties;

        public RedisSupportConfig(IdProperties idProperties) {
            this.idProperties = idProperties;
        }

        @Bean
        @ConditionalOnProperty(prefix = IdProperties.CONFIG_PREFIX, name = "assigner-type", havingValue = "REDIS")
        public SnowflakeWorkerAssigner idGeneratorBuildableRedis(RedisTemplate redisTemplate) {
            return new RedisSnowflakeWorkerAssigner(dataCenterName, idProperties, redisTemplate);
        }
    }
}

==> cloudt-boot-starter-jpa-3.2.6.29-0315-20240315.055048-1-sources.jar: com/elitescloud/boot/jpa/support/id/provider/snowflake/config/SnowflakeConfig.java <==
package com.elitescloud.boot.jpa.support.id.provider.snowflake.config;

import com.elitescloud.boot.jpa.support.id.config.IdProperties;
import com.elitescloud.boot.jpa.support.id.provider.snowflake.SnowflakeProvider;
import com.elitescloud.boot.jpa.support.id.provider.snowflake.assigner.DatabaseSnowflakeWorkerAssigner;
import com.elitescloud.boot.jpa.support.id.provider.snowflake.assigner.ManualSnowflakeWorkerAssigner;
import com.elitescloud.boot.jpa.support.id.provider.snowflake.assigner.RedisSnowflakeWorkerAssigner;
import com.elitescloud.boot.jpa.support.id.provider.snowflake.assigner.SnowflakeWorkerAssigner;
import com.elitescloud.boot.jpa.support.id.util.IdTool;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.jdbc.JdbcProperties;
import org.springframework.context.EnvironmentAware;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Import;
import org.springframework.core.env.Environment;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.lang.NonNull;

import javax.sql.DataSource;

/**
 * 雪花算法配置.
 *
 * @author Kaiser（wang shao）
 * @date 2022/12/8
 */
@ConditionalOnProperty(prefix = IdProperties.CONFIG_PREFIX, name = "gen-type", havingValue = "SNOWFLAKE", matchIfMissing = true)
@Import({SnowflakeConfig.RedisSupportConfig.class})
public class SnowflakeConfig implements EnvironmentAware {
    @Value("${spring.application.name:#{'unknown'}}")
    private String dataCenterName;

    private final IdProperties idProperties;
    private final DataSource dataSource;
    private Environment environment;

    public SnowflakeConfig(IdProperties idProperties, DataSource dataSource) {
        this.idProperties = idProperties;
        this.dataSource = dataSource;
    }

    @Override
    public void setEnvironment(@NonNull Environment environment) {
        this.environment = environment;
    }

    @Bean
    public SnowflakeProvider snowflakeProvider(SnowflakeWorkerAssigner workerAssigner) {
        return new SnowflakeProvider(workerAssigner);
    }

    @Bean
    @ConditionalOnProperty(prefix = IdProperties.CONFIG_PREFIX, name = "assigner-type", havingValue = "MANUAL", matchIfMissing = true)
    public SnowflakeWorkerAssigner idGeneratorBuildableManual() {
        return new ManualSnowflakeWorkerAssigner(idProperties);
    }

    @Bean
    @ConditionalOnProperty(prefix = IdProperties.CONFIG_PREFIX, name = "assigner-type", havingValue = "DATABASE")
    public SnowflakeWorkerAssigner idGeneratorBuildableDatabase(JdbcProperties properties) {
        var jdbcTemplate = IdTool.buildJdbcTemplate(environment, dataSource, idProperties, properties);
        return new DatabaseSnowflakeWorkerAssigner(dataCenterName, idProperties, jdbcTemplate);
    }

    @Configuration
    @ConditionalOnClass(RedisTemplate.class)
    static class RedisSupportConfig {

        @Value("${spring.application.name:#{'unknown'}}")
        private String dataCenterName;

        private final IdProperties idProperties;

        public RedisSupportConfig(IdProperties idProperties) {
            this.idProperties = idProperties;
        }

        @Bean
        @ConditionalOnProperty(prefix = IdProperties.CONFIG_PREFIX, name = "assigner-type", havingValue = "REDIS")
        public SnowflakeWorkerAssigner idGeneratorBuildableRedis(RedisTemplate redisTemplate) {
            return new RedisSnowflakeWorkerAssigner(dataCenterName, idProperties, redisTemplate);
        }
    }
}
